\ProvidesClass{icmsec}[2004/10/14 v0.2, by Ge Xiangyang and Zhang Lin-bo]
%
% Class Options:
%	preprint	- Preprint (default). TO BE IMPLEMENTED!!!
%	phd		- PhD thesis (default)
%	master		- Master thesis
%	makeindex	- '\uepackage{makeidx}' and '\makeindex'
%	preview		-
%	everb		- Cast verbatim environment
%
% Change log:
%	20040925: v0.2,  makeindex, preview, everb ѡ
%	20040920: first version (0.1)

\newif\ifPreprint\Preprinttrue
\newif\ifPhD\PhDtrue
\newif\ifMakeindex\Makeindexfalse
\newif\ifPreview\Previewfalse
\newif\ifEverb\Everbfalse

\DeclareOption{phd}{\PhDtrue\Preprintfalse}
\DeclareOption{master}{\PhDfalse\Preprintfalse}
\DeclareOption{preprint}{\Preprinttrue}
\DeclareOption{makeindex}{\Makeindextrue}
\DeclareOption{preview}{\Previewtrue}
\DeclareOption{everb}{\Everbtrue}
\ProcessOptions

\let\CCTCJKfonts=1
\LoadClass[11pt,twoside]{cctbook}[2004/09/20]
\RequirePackage{ifpdf}
\RequirePackage{graphicx}
\ifMakeindex
  \RequirePackage{makeidx}
  \AtEndDocument{\printindex}
  \makeindex
\fi

\RequirePackage{amsthm}
\RequirePackage{amsmath}

\ifEverb
  \usepackage{everb}
  %\everbsetup{number=false, boxcolor=green, fgcolor=red, escape=12}
  \everbsetup{number=false, escape=12}
  \renewenvironment{verbatim}
    {\medskip\everbatim@{verbatim}[number=false]}
    {\medskip}
\fi

\ifpdf
  \RequirePackage[CJKbookmarks,hyperindex]{hyperref}
\else
  \ifPreview
    \RequirePackage[CJKbookmarks,hypertex,hyperindex]{hyperref}
  \else
    \RequirePackage[CJKbookmarks,dvipdfm,hyperindex]{hyperref}
  \fi
\fi

\endlinechar -1

%------------------------ Page layout ----------------------------------

\headsep=8mm
\headheight=6mm
\topmargin=.5cm
\oddsidemargin=.75cm
\evensidemargin=.75cm
\textwidth=145mm
\textheight=210mm
\footskip=8mm
\doublerulesep=0.5pt

%-------------------------- Cover page ----------------------------
\let\@title\strut \let\@headtitle\strut
\renewcommand\title[2][]{\def\@title{#2}\def\@headtitle{#1}
  \ifx\@headtitle\@empty\def\@headtitle{\@title}\fi}

\let\@author\strut		\def\author#1{\def\@author{#1}}
\let\@supervisor\@empty		\def\supervisor#1{\def\@supervisor{#1}}
\let\@submissiondate\@empty	\def\submissiondate#1{\def\@submissiondate{#1}}
\let\@defensedate\@empty	\def\defensedate#1{\def\@defensedate{#1}}
\let\@chairman\@empty		\def\chairman#1{\def\@chairman{#1}}
\let\@field\@empty		\def\field#1{\def\@field{#1}}
\let\@classification\@empty	\def\classification#1{\def\@classification{#1}}
\let\@UDC\@empty		\def\UDC#1{\def\@UDC{#1}}
\let\@confidentiality\@empty \def\confidentiality#1{\def\@confidentiality{#1}}
\let\@serialno\@empty		\def\serialno#1{\def\@serialno{#1}}

\def\maketitle{
  \frontmatter
  \bgroup
  \def\entry##1##2##3{%
    \multicolumn{##1}{l}{\underline{\hbox to ##2{\hfil##3\hfil}}}}
  \renewcommand\arraystretch{1.5}
  \renewcommand\tabcolsep{\z@}
  \thispagestyle{empty}
  \setcounter{page}{0}
  \pagenumbering{roman}
  \begin{center}
  \begin{tabular}{llcll}
     & \entry{1}{3.2cm}{\@classification} & \hspace*{5cm}
    ܼ   & \entry{1}{3.2cm}{\@confidentiality} \\
    UDC    & \entry{1}{3.2cm}{\@UDC} & \hspace*{5cm}
       & \entry{1}{3.2cm}{\@serialno}
  \end{tabular}
  \end{center}
  \vfill
  \begin{center}
    {\Huge йѧԺоԺ\\[8pt]\ifPhD ʿ\else ˶ʿ\fi ѧλ}\\[2cm]
    {\rmfamily\Large\zihao{3}\@title}\\*[-0.7\baselineskip]
    \rule[\z@]{\textwidth}{.4\p@}\\*[2cm]
    {\normalsize\rmfamily\underline{\@author}}
  \end{center}
  \vfill
  \large\fangsong\zihao{4}
  \def\mlines##1{\vbox to\z@{\hsize 3cm\vss\baselineskip 1em\centering ##1}}
  \begin{center}
  \begin{tabular}{llll}
    ָʦ	&\entry{3}{11.6cm}{\@supervisor}\\
		&\entry{3}{11.6cm}{йѧԺѧϵͳѧоԺ}\\
    ѧλ&\entry{1}{3.7cm}{\ifPhD ʿ\else ˶ʿ\fi} &
    ѧרҵ&\entry{1}{5cm}{\@field}\\
    ύ&\entry{1}{3.7cm}{\mlines{\@submissiondate}} &
    Ĵ&\entry{1}{5cm}{\mlines{\@defensedate}}\\
    λ	&\entry{3}{11.6cm}{йѧԺѧϵͳѧоԺ}\\
    ѧλ赥λ&\entry{3}{11.6cm}{йѧԺоԺ}\\
    \multicolumn{3}{r}{ίԱϯ} & \entry{1}{4cm}{\@chairman}
  \end{tabular}
  \end{center}
  \setcounter{page}{1}
  \egroup
  %\standard@zihaofalse
}

%----------------------- Running heads ---------------------------------
\def\ps@myheadings{\global\let\@oddfoot\@empty\global\let\@evenfoot\@empty
  \gdef\@oddhead{\rm\small\leftmark\hss\thepage
	\lower1ex\llap{\rule[\z@]{\textwidth}{0.15\p@}}}
  \gdef\@evenhead{\rm\small\thepage\hss\@headtitle
	\lower1ex\llap{\rule[\z@]{\textwidth}{0.15\p@}}}
}
\pagestyle{empty}

%------------------------ Abstract & Keywords -------------------------
\newenvironment{abstract}[1][]
  {\cleardoublepage\setcounter{page}{1}\pagestyle{myheadings}
   \chapter{ժ^^a1^^a1Ҫ}
   \def\English##1##2##3{{\clearpage
     \renewcommand\baselinestretch{1}
     \@openrightfalse\chapter*{##1}
     \begin{center}
       ##2\\
       Directed by ##3
     \end{center}\bigskip\par}}}
  {\cleardoublepage\tableofcontents
   \aftergroup\mainmatter\setcounter{page}{1}\setcounter{chapter}{0}}

%------------------------ Chapters/sections -------------------------
\def\chapterformat{\Large\bfseries\centering}
\def\sectionformat{\large\bfseries}
\def\subsectionformat{\bfseries}
\def\subsubsectionformat{\normalfont\rm}

%----------------------- Theorems -----------------------------------
\newtheorem{theorem}{{}}[chapter]
\newtheorem{proposition}[theorem]{{}}
\newtheorem{lemma}[theorem]{{}}
\newtheorem{corollary}[theorem]{{}}
\newtheorem{definition}{{}}[section]
\newtheorem{example}{{}}[section]
\renewcommand\proofname{֤}

%----------------------- Appendices ---------------------------------
\renewcommand\appendixname{¼\,\Alph{chapter}}

%----------------------- Publications -------------------------------
\newenvironment{publications}[1]
  {\renewcommand\bibname{Ŀ¼}\begin{thebibliography}{#1}}
  {\end{thebibliography}}

%----------------------- Acknowledgement ----------------------------
\newcommand\acknowledgement{\backmatter\chapter{^^a1^^a1л}}

%----------------------- Caption ------------------------------------
\setlength\abovecaptionskip{7\p@}
\setlength\belowcaptionskip{7\p@}

\raggedbottom

\endlinechar `\^^M
\endinput
